<TS version="2.1" language="ast_ES">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Fai clic col botón drechu pa editar la dirección o la etiqueta</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Crear una nueva dirección</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nueva</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Copiar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Cerrar</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Eliminar la dirección seleccionada de la llista</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Introduz la dirección o etiqueta pa buscar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Exportar los datos de la solapa actual a un ficheru</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Exportar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Eliminar</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Escueye la dirección a la que mandar los coins</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Escueye la dirección pa recibir los coins</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;Escoyer</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Estes son les tuyes direcciones de Bitcoin pa mandar pagos. Siempre revisa la cantidá y la dirección de recibimientu antes de mandar los coins.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Estes son les tuyes direcciones de Bitcoin pa recibir pagos. Usa el botón 'Crear nueva dirección de recibimientu' na solapa de recibir pa crear nueves direcciones.
La firma ye possible solamentu con direcciones del tipu 'legacy'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Copiar Dirección</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Copiar &amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Editar</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Exportar Llista de Direcciones</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ficheru separao por comas</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Hubo un error intentando guardar la llista de direcciones en %1. Por favor, intenta de nuevo. </translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Enviando direcciones - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Recibiendo direcciones - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Recibiendo direcciones</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Dirección</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Diálogu de la frase de seguridá</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Introduz la frase de seguridá</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Nueva frase de seguridá</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Repite la nueva frase de seguridá</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Amosar la frase de seguridá</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Cifrar la cartera</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Esta operación necesida la frase de seguridá de la cartera pa desbloquearla.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Desbloquear la cartera</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Cambiar la frase de seguridá</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Confirmar el cifrado de la cartera</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Advertencia: Si cifras la tua cartera y pierdes la frase de seguridá, ¡perderás &lt;b&gt;TOOS LOS TUYOS BITCOINS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">¿Estás seguru de que quieres cifrar la tua cartera?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Cartera cifrada</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Introduz la nueva frase de seguridá pa la cartera. &lt;br/&gt;Por favor, usa una frase de seguridá de &lt;b&gt;diez o más carauteres aleatorios&lt;/b&gt;, o &lt;b&gt;de ocho o más palabres.&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Introduz la frase de seguridá antigua y la nueva frase de seguridá pa la cartera.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Continuar</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished">Atrás</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Recuerda que cifrar la tua cartera nun puede protexer completamente los tuyos bitcoins de ser robados por malware que infecte tu ordenador.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Cartera a cifrar</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">La tua cartera ta a punto de ser cifrada.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">La tua cartera ta cifrada agora.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">IMPORTANTE: Cualquier copia de seguridá anterior que hayas fechu del ficheru de la cartera debe ser reemplazada pola nueva copia cifrada que se xeneró. Por razones de seguridá, las copias de seguridá anteriores del ficheru de la cartera sin cifrar quedarán inútiles en cuanto empieces a usar la nueva cartera cifrada.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Falló el cifrado de la cartera</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Falló el cifrado de la cartera debido a un error internu. La tua cartera nun fue cifrada.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Les frases de seguridá fornecies nun coinciden.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Falló el desbloqueo de la cartera</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">La frase de seguridá introducida pa la descifradura de la cartera foi incorrecta.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">La frase de seguridá introducida pa la descifradura de la cartera ye incorrecta. Contién un caráuter null (es decir, un byte cero). Si la frase de seguridá foi puesta con una versión d'este software anterior a la 25.0, por favor, intenta de nuevo con solamente los carauteres hasta — pero non incluyendo — el primer caráuter null. Si ye exitósu, por favor, pon una nueva frase de seguridá pa evitar este problema n'el futuru.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">La frase de seguridá de la cartera fue cambiada con éxito.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Falló el cambiu de la frase de seguridá</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">La frase de seguridá antigua introducida pa la descifradura de la cartera ye incorrecta. Contién un caráuter null (es decir, un byte cero). Si la frase de seguridá foi puesta con una versión d'este software anterior a la 25.0, por favor, intenta de nuevo con solamente los carauteres hasta — pero non incluyendo — el primer caráuter null.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Advertencia: ¡La tecla de Bloq Mayús ta activada!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/Máscara de subrede</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Prohibíu hasta</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">El ficheru de configuraciones %1 podría estar corruptu o ser inválidu.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Excepción descontrolada</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Ocurrió un error fatal. %1 ya nun puede seguir funcionando con seguridá y va cerrase.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Error internu</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Ocurrió un error internu. %1 intentará seguir funcionando con seguridá. Este ye un bug inesperao que pue ser reportao como se describe más baxo.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">¿Quieres restablecer les configuraciones a los valores predeterminados, o abortar senza facer cambeos?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Ocurrió un error fatal. Verifica que'l ficheru de configuraciones se pue escribir o intenta executar con -nosettings.</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 entá nun salió con seguridá…</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Visión xeneral</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Amosar una visión xeneral de la cartera</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Tratos</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">S&amp;alir</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Zarrar l'aplicación</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Acerca de %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Amosar información sobre %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Amosar información sobre Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Modificar les opciones de configuración pa %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Crear una nueva cartera</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Minimizar</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cartera:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Actividá de rede desactivada.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">El proxy ta &lt;b&gt;activáu&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Enviar monedas a una dirección de Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Facer una copia de seguridá de la cartera n'otra ubicación</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Cambiar la frase de seguridá usá para el cifrado de la cartera</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Enviar</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Enviar</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Opciones…</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Cifrar Cartera…</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Cifrar les claves privades que pertenezen a la tua cartera</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Copia de seguridá de la cartera…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Cambiar la frase de seguridá…</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Firmar &amp;mensaje…</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Firmar mensajes con les tuyas direcciones de Bitcoin pa probar que les tienes</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Verificar mensaje…</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Verificar los mensajes pa asegurar que fueron firmados con les direcciones de Bitcoin especificaes</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;Cargar PSBT dende el ficheru…</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Abrir &amp;URI…</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Cerrrar la cartera…</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Crear cartera…</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Cerrrar toles carteres…</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Ficheru</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Configuraciones</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Ayuda</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Barra d'hermintes de les pestanyes</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Sincronizando encabezaos (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Sincronizando con la rede…</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Indexando bloques nel ficheru…</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Procesando bloques nel ficheru…</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Conectando con pares…</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Solicitar pagamientos (xenera códigos QR y bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Amosar la llista de direcciones y etiquetes de envío usáes</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Amosar la llista de direcciones y etiquetes de recepción usáes</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Opciones de la llinia de comandos</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Procesáronse %n bloque(s) del historial de transacciones.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 detrás</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Poniéndome al día…</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">El últimu bloque recibíu foi xeneráu fai %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Les transacciones depués d'esto aún nun serán visibles.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Advertencia</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Información</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Actualizáu</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Cargar Transacción de Bitcoin Parcialmente Firmada</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">Cargar PSBT dende el &amp;portapapeles…</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Cargar Transacción de Bitcoin Parcialmente Firmada dende el portapapeles</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Ventana de nódulu</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Abrir la consola de depuración y diagnóstico del nódulu</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Direcciones de envío</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Direcciones de recepción</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Abrir un bitcoin: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Abrir cartera</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Abrir una cartera</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Cerrrar cartera</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Restaurar cartera…</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Restaurar una cartera dende un ficheru de copia de seguridá</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Cerrrar toles carteres</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Migrar cartera</translation>
    </message>
    <message>
        <source>Migrate a wallet</source>
        <translation type="unfinished">Migrar una cartera</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Amosar el mensaxe d’ayuda de %1 pa ver una llista de les posibles opciones de la llinia de comandos de Bitcoin</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Enmascarar valores</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">Enmascarar los valores na llingüeta Resumen</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Nun hai carteres disponibles</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Datos de la cartera</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">Cargar copia de seguridá de la cartera</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Restaurar cartera</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Nome de la cartera</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Ventana</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Ampliar</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Ventana principal</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">Cliente %1</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Anubrir</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">&amp;Amosar</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n conexión(es) activa(es) a la rede de Bitcoin</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Calca pa más aicione.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Amosar la llingüeta de pares</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Desactivar l'actividá de rede</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Activar l'actividá de rede</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">Presincronizando encabezaos (%1%)…</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Fecha: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Cantidá: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>MigrateWalletActivity</name>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Migrar cartera</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Abrir cartera</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Restaurar cartera</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Cerrrar cartera</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Cerrrar toles carteres</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Nome de la cartera</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Ventana</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Continuar</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Dirección</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Ventana de nódulu</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cartera:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ficheru separao por comas</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Dirección</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Recibiendo direcciones</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Crear una nueva cartera</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Exportar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Exportar los datos de la solapa actual a un ficheru</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Datos de la cartera</translation>
    </message>
    </context>
</TS>